==> jellyfish-chat-0.0.1.tar.gz: jellyfish-chat-0.0.1/fastapi_chat/chat/app.py <==
from datetime import datetime

import sentry_sdk
from fastapi import Depends, FastAPI, HTTPException, WebSocket
from sentry_sdk.integrations.asgi import SentryAsgiMiddleware
from starlette.websockets import WebSocketDisconnect
from websockets.exceptions import ConnectionClosedOK

from .manager import connection_manager
from .redis_connector import connect_redis
from .settings import (
    BrokerSettings,
    DjangoServerSettings,
    GlobalSettings,
    get_broker_settings,
    get_django_settings,
    get_global_settings,
)


sentry_sdk.init(
    dsn=get_global_settings().sentry_dsn,
    environment=get_global_settings().environment,
)
app = FastAPI()

try:
    app.add_middleware(SentryAsgiMiddleware)
except:
    # pass silently if the Sentry integration failed
    pass


@app.on_event("startup")
async def startup_event():
    redis = await connect_redis()
    app.state.redis = redis


@app.websocket("/chat")
async def websocket_endpoint(
    websocket: WebSocket,
    token: str,
    django_settings: DjangoServerSettings = Depends(get_django_settings),
    broker_settings: BrokerSettings = Depends(get_broker_settings),
    global_settings: GlobalSettings = Depends(get_global_settings),
):
    user_id = await connection_manager.check_auth(token, django_settings)
    if not user_id:
        raise HTTPException(status_code=401, detail="Invalid token")
    await connection_manager.connect(websocket, user_id)
    if global_settings.capture_messages:
        sentry_sdk.capture_message(
            f"{datetime.now()}, successfully connected user {user_id}",
            level="info",
        )

    (channel,) = await app.state.redis.subscribe(broker_settings.channel_name)
    try:
        while await channel.wait_message():
            msg = await channel.get()
            if global_settings.capture_messages:
                sentry_sdk.capture_message(
                    f"{datetime.now()}, new message from subscriber {msg}"
                )
            await connection_manager.broadcast(msg)
    except WebSocketDisconnect as exc:
        if global_settings.capture_messages:
            sentry_sdk.capture_message(
                f"{datetime.now()}, exception websocket disconnect {exc}"
            )
    except ConnectionClosedOK as exc:
        if global_settings.capture_messages:
            sentry_sdk.capture_message(
                f"{datetime.now()}, exception closed OK {exc}"
            )
    finally:
        channel.close()
        await connection_manager.disconnect(websocket)

==> jellyfish-chat-0.0.2b0.tar.gz: jellyfish-chat-0.0.2b0/fastapi_chat/chat/app.py <==
from datetime import datetime

import sentry_sdk
from broadcaster import Broadcast
from fastapi import Depends, FastAPI, HTTPException, WebSocket
from sentry_sdk.integrations.asgi import SentryAsgiMiddleware
from websockets.exceptions import ConnectionClosedOK

from .manager import connection_manager
from .settings import (
    DjangoServerSettings,
    GlobalSettings,
    get_broker_settings,
    get_django_settings,
    get_global_settings,
)


sentry_sdk.init(
    dsn=get_global_settings().sentry_dsn,
    environment=get_global_settings().environment,
)
broker_settings = get_broker_settings()
broadcast = Broadcast(
    f"redis://{broker_settings.host}:{broker_settings.port}/{broker_settings.db}"
)
app = FastAPI(
    on_startup=[broadcast.connect], on_shutdown=[broadcast.disconnect]
)

try:
    app.add_middleware(SentryAsgiMiddleware)
except:
    # pass silently if the Sentry integration failed
    pass


@app.websocket("/chat")
async def websocket_endpoint(
    websocket: WebSocket,
    token: str,
    django_settings: DjangoServerSettings = Depends(get_django_settings),
    global_settings: GlobalSettings = Depends(get_global_settings),
):
    user_id = await connection_manager.check_auth(token, django_settings)
    if not user_id:
        raise HTTPException(status_code=401, detail="Invalid token")
    await connection_manager.connect(websocket)
    if global_settings.capture_messages:
        sentry_sdk.capture_message(
            f"{datetime.now()}, successfully connected user {user_id}",
            level="info",
        )

    try:
        async with broadcast.subscribe(channel="chat_channel") as subscriber:
            async for event in subscriber:
                await connection_manager.send_if_needed(msg=event.message, user_id=user_id, websocket=websocket)
    except ConnectionClosedOK as exc:
        if global_settings.capture_messages:
            sentry_sdk.capture_message(
                f"{datetime.now()}, exception closed OK {exc}"
            )
